@@ -6,7 +6,7 @@ import re
 
 from collections import namedtuple
 
-__version__ = '1.3.1'
+__version__ = '2.0.0'
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
 __homepage__ = 'http://github.com/celery/sphinx_celery'
@@ -14,7 +14,7 @@ __docformat__ = 'restructuredtext'
 
 # -eof meta-
 
-__all__ = ['get_html_templates_path', 'get_html_theme_path']
+__all__ = ['get_html_templates_path', 'get_html_theme_path', 'setup']
 
 version_info_t = namedtuple('version_info_t', (
     'major', 'minor', 'micro', 'releaselevel', 'serial',
@@ -39,3 +39,7 @@ def get_html_templates_path():
         os.path.abspath(os.path.dirname((__file__))),
         'templates',
     )
+
+
+def setup(app):
+    app.add_html_theme('sphinx_celery', os.path.abspath(os.path.dirname(__file__)))
