@@ -14,8 +14,14 @@ def wrapped_getargspec(fun, *args, **kwargs):
         except AttributeError:
             break
     return inspect.getargspec(fun, *args, **kwargs)
+
+
 _autodoc.getargspec = wrapped_getargspec
 
 
 def setup(app):
     app.require_sphinx('1.0')
+
+    return {
+        'parallel_read_safe': True
+    }
